==> kleopatra_16.04.2.orig.tar.xz: kleopatra-16.04.2/src/commands/deletecertificatescommand.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    deletecertificatescommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2007 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMANDS_DELETECERTIFICATESCOMMAND_H__
#define __KLEOPATRA_COMMANDS_DELETECERTIFICATESCOMMAND_H__

#include "command.h"

namespace Kleo
{
class DeleteCertificatesCommand : public Command
{
    Q_OBJECT
public:
    explicit DeleteCertificatesCommand(QAbstractItemView *view, KeyListController *parent);
    explicit DeleteCertificatesCommand(KeyListController *parent);
    ~DeleteCertificatesCommand();

    /* reimp */ static Restrictions restrictions()
    {
        return NeedSelection;
    }

private:
    void doStart() Q_DECL_OVERRIDE;
    void doCancel() Q_DECL_OVERRIDE;

private:
    class Private;
    inline Private *d_func();
    inline const Private *d_func() const;
    Q_PRIVATE_SLOT(d_func(), void slotDialogAccepted())
    Q_PRIVATE_SLOT(d_func(), void slotDialogRejected())
    Q_PRIVATE_SLOT(d_func(), void pgpDeleteResult(GpgME::Error))
    Q_PRIVATE_SLOT(d_func(), void cmsDeleteResult(GpgME::Error))
};
}

#endif // __KLEOPATRA_COMMANDS_DELETECERTIFICATESCOMMAND_H__

==> kleopatra-17.07.90.tar.xz: kleopatra-17.07.90/src/commands/deletecertificatescommand.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    deletecertificatescommand.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2007 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_COMMANDS_DELETECERTIFICATESCOMMAND_H__
#define __KLEOPATRA_COMMANDS_DELETECERTIFICATESCOMMAND_H__

#include "command.h"

namespace Kleo
{
class DeleteCertificatesCommand : public Command
{
    Q_OBJECT
public:
    explicit DeleteCertificatesCommand(QAbstractItemView *view, KeyListController *parent);
    explicit DeleteCertificatesCommand(KeyListController *parent);
    ~DeleteCertificatesCommand();

    /* reimp */ static Restrictions restrictions()
    {
        return NeedSelection;
    }

private:
    void doStart() override;
    void doCancel() override;

private:
    class Private;
    inline Private *d_func();
    inline const Private *d_func() const;
    Q_PRIVATE_SLOT(d_func(), void slotDialogAccepted())
    Q_PRIVATE_SLOT(d_func(), void slotDialogRejected())
    Q_PRIVATE_SLOT(d_func(), void pgpDeleteResult(GpgME::Error))
    Q_PRIVATE_SLOT(d_func(), void cmsDeleteResult(GpgME::Error))
};
}

#endif // __KLEOPATRA_COMMANDS_DELETECERTIFICATESCOMMAND_H__
